# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .client_facing_loinc import ClientFacingLoinc
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ClientFacingResult(UniversalBaseModel):
    id: int
    name: str
    slug: str
    lab_id: typing.Optional[int] = None
    provider_id: typing.Optional[str] = None
    required: bool
    loinc: typing.Optional[ClientFacingLoinc] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
